define([
  './general/overviewGeneralCtrl',
  './mitre/overviewMitreCtrl',
  './mitre-ids/overviewMitreIdsCtrl',
  './welcome/overviewWelcomeCtrl',
  './audit/overviewAuditCtrl',
  './fim/overviewFimCtrl',
  './virustotal/overviewVirusTotalCtrl',
  './aws/awsCtrl',
  './osquery/osqueryCtrl',
  './docker/dockerCtrl',
  './scap/overviewOpenScapCtrl',
  './gdpr/overviewGdprCtrl',
  './pci/overviewPciCtrl',
  './ciscat/ciscatCtrl',
  './policy-monitoring/overviewPolicyMonitoringCtrl',
  './vulnerabilities/overviewVulnerabilitiesCtrl',
  './sca/overviewSCACtrl',
  './hipaa/overviewHipaaCtrl',
  './nist/overviewNistCtrl',
], function () {})
